Skip to contents

Flushes buffered additions and deletions to the index and refreshes the reader so they become visible to tnt_search().

Usage

tnt_commit(idx)

Arguments

idx

A tnt_index.

Value

The tnt_index, invisibly.

Examples

sch <- tnt_schema(body = tnt_text(stemmer = "english"))
idx <- tnt_index(schema = sch)
tnt_add(idx, data.frame(body = "hello")) |> tnt_commit()